aerosoltools.loaders.Load_Grimm_file — aerosoltools 0.1.0 documentation

# aerosoltools.loaders.Load_Grimm_file

aerosoltools.loaders.Load_Grimm_file(file)

  Load data from a Grimm spectrometer file, either software-exported or instrument-direct. The file type is detected automatically and passed to the correct loader.

  ## Parameters

  filestr

    Path to the Grimm data file.

  ## Returns

  grimmAerosol2D

    Aerosol2D object with datetime-resolved particle concentration data.

  ## Raises

  Exception

    If the file format is not recognized.

  Parameters:

    file (str)

  Return type:

    Aerosol2D